
/**
 * Wrap the selection bounds in a object usable class.
 * @param selection
 * @returns {{bottom: *, UnitValue, right: *, top: *, left: *, x: *, y1: *, width: *, x1: *, y: *, y2: *, x2: *, height: *}}
 * @constructor
 */
var SelelectionDimensions = function() {

    /**
     * The selection bounds.
     * @private
     */
    var _bounds = activeDocument.selection.bounds;

    /**
     * The UnitValue.type
     * @private
     */
    var _unit   = _bounds[0].type;

    /**
     * The left edge coordinate.
     * @private
     */
    var _left   = _bounds[0].value;

    /**
     * The top edge coordinate.
     * @private
     */
    var _top    = _bounds[1].value;

    /**
     * The right edge coordinate.
     * @private
     */
    var _right  = _bounds[2].value;

    /**
     * The bottom edge coordinate.
     * @private
     */
    var _bottom = _bounds[3].value;

    /**
     * The selection width.
     * @type {number}
     * @private
     */
    var _width  = new Number(_right - _left);

    /**
     * The selection height.
     * @type {number}
     * @private
     */
    var _height = new Number(_bottom - _top);


    /**
     * The public interface for this class.
     */
    return {
        unit      : _unit,
        top       : _top,
        left      : _left,
        right     : _right,
        bottom    : _bottom,
        x         : _left,
        x1        : _left,
        x2        : _right,
        y         : _top,
        y1        : _top,
        y2        : _bottom,
        width     : _width,
        height    : _height
    }
};
