/**
 * Settings dialog object.
 * @returns {*}
 * @constructor
 */
SettingsDialog = function(Config) {

    /**
     * Save the API key to the settings file.
     * @param key
     * @returns {*}
     * @private
     */
    var _saveApiKey = function(key) {

        try {
            var result = Utils.write_json_file(
                Config.SETTINGS_FILE,
                {key : key}
            );

            if (result) {
                return true;
            }
            else {
                var saveError = new SaveApiKeyError(
                    'API Key was not saved because of an error'
                );
                host.logger.error(saveError);
                throw saveError;
            }
        }
        catch(e) {
            host.logger.error(e);
            return e;
        }
    };

    var _dialog;

    try {
        _dialog = Utils.window("dialog", "Remove BG Settings", 350, 190 );
    }
    catch(e) {
        return new SettingsDialogError('Utils.window failed : ' + $.stack, $.stack);
    }

    try {

        var keyHolder = Config.API_KEY,
            obfuscatedKey = '';

        if (typeof(Config.API_KEY) == 'string') {
            obfuscatedKey = Config.API_KEY.replace(/./g, "*");
        }

        // Profile controls

        _dialog.getApiKeyBtn   = _dialog.add('button', [230, 15, 280, 45], 'Get API Key', {name: 'getkey'});
        _dialog.getApiKeyBtn.onClick = function() {

            _dialog.close();

            // Send an event to the UI to reload.
            new CustomEvent(
                Events.OPEN_URL,
                JSON.stringify({url: Config.PROFILE_API_KEY})
            ).dispatch();

            return false;
        }

        _dialog.apiKeyDummy= _dialog.add('edittext', [30, 50, 320, 90], obfuscatedKey);
        _dialog.apiKeyDummy.active = false;
        _dialog.apiKeyDummy.characters = 32;

        _dialog.apiKeyLabel   = _dialog.add('statictext', [30, 10, 320, 50], 'API Key');
        _dialog.apiKey        = _dialog.add('edittext',   [30, 50, 320, 90], Config.API_KEY);
        _dialog.apiKey.active = false;
        _dialog.apiKey.characters = 32;
        _dialog.apiKey.hide();

        // Prevent editing the apiKey field directly.

        _dialog.apiKey.onActivate = function() {
            _dialog.apiKey.active = false;
            _dialog.apiKey.text = keyHolder;
        }

        //  Spoof a password field.

        _dialog.apiKeyDummy.onActivate = function() {
            _dialog.apiKeyDummy.text = keyHolder;
        }

        _dialog.apiKeyDummy.onChange = function() {
            _dialog.apiKey.text = _dialog.apiKeyDummy.text;
            keyHolder = _dialog.apiKeyDummy.text;
        }

        _dialog.apiKeyDummy.onDeactivate = function() {
            // keyHolder = _dialog.apiKey.text;
            _dialog.apiKeyDummy.text = keyHolder.obfuscate();
        }

        // Cancel button

        _dialog.closeBtn = _dialog.add('button', [30, 100, 160, 160], 'Close', {name: 'close'});
        _dialog.closeBtn.onClick = function() {
            keyHolder = "";
            _dialog.close();
        };

        // Save Api Key button

        _dialog.saveBtn = _dialog.add('button', [170, 100, 320, 160], 'Save', {name: 'save'});
        _dialog.saveBtn.onClick = function() {

            try {
                _dialog.apiKey.text = keyHolder;

                host.logger.info('Save API key : ' + _dialog.apiKey.text);

                Config.API_KEY = _dialog.apiKey.text;

                // Save the API Key
                _saveApiKey(_dialog.apiKey.text);

                _dialog.close();

                // Send an event to the UI to reload.
                new CustomEvent(
                    Events.KEY_SAVED,
                    JSON.stringify({saved: true})
                ).dispatch();
            }
            catch(e) {
                host.logger.error(
                    new SaveApiKeyError(e.message, e.stack)
                );
            }

            return false;
        };

        return _dialog;
    }
    catch(e) {
        return new SettingsDialogError('The SettingsDialog could not be created. Error : ' + e);
    }
};

